from setuptools import setup

setup(
    name = 'temperatura',
    version = '2.0.0',
    author = 'Lissandro',
    packages = ['temperatura'],
    description = 'Um simples conversor de temperatura (Celsius - Fahrenheit)',
    long_description = 'Um simples conversor de temperatura, com funções para '
                        + 'conversão de Celsius para Fahrenheit e vice-versa, '
                        + 'usado para um aprendizado na criação de pacotes',
    url="https://github.com/lissandro1/li-simple-package-template",
    license = 'MIT'
)